Lua_ExpeditionStoreWindow = class("Lua_ExpeditionStoreWindow", Lua_Window);
function Lua_ExpeditionStoreWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ExpeditionStoreWindow";
	self.skinName = "ExpeditionDiscountStoreWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ExpeditionStoreWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.des:setLangValue(330025);
	self.btnFunc:setEnable(false);

	self.itemList = Lua_DragList.new(self.content, 620, 250, Lua_AxisDefine.Horizontal);
	self.itemList:setLocation(0, -137, 0);
	self.itemList.canDrag = false;
	self.itemList:setListCell(Lua_ExpeditionStoreItem, 150, 200, 1);

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setLocation(0, -342, 0);
	self.buttonList:setButtonCell(Lua_ExpeditionStoreBtnItem);
	self.buttonList:setButtonItem(172, 65);
	self.buttonList:setClickCallBack(self, self.onButtonClick);

	self:addLuaEvent("EXPEDITION_STORE_INFO", self, self.updateShowInfo);
	self:addLuaEvent("EXPEDITION_DISCOUNTSTORE_SELECT", self, self.onStoreItemSelected);
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sStoreInfo();
end

function Lua_ExpeditionStoreWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	self.data = nil;
	self.itemData = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionStoreWindow:updateShowInfo(msg)
	self.buttonList:setData(msg.shop_info_list);
	self.buttonList.selectedIdx = nil;
	self.buttonList:setSelected(self.selectedIdx);
end

function Lua_ExpeditionStoreWindow:onButtonClick(index, data)
	self.selectedIdx = index;
	self.data = data;
	self.itemList:setArrayData(data.item_list);
end

function Lua_ExpeditionStoreWindow:onStoreItemSelected(data)
	self.itemData = data;

	local info = DataCenter.expeditionUtil:getStoreInfo(data.shop_id);
	local name = getConfig("item", info.item[1], "name");
	local haveCount = DataCenter.packData:getItemCountById(info.item[1]);
	local tipsData = { des = LanUtil.formateStr(330028, name, tostring(haveCount)), btnType = 1, owner = self, sureFun = self.onSureBuy };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ExpeditionStoreWindow:onSureBuy()
	if self.data == nil or self.itemData == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sStoreBuy(self.itemData.shop_id, self.data.stage_id, self.data.location, 0, self.itemData.index);
end










Lua_ExpeditionStoreBtnItem = class("Lua_ExpeditionStoreBtnItem", Lua_ButtonCell)
function Lua_ExpeditionStoreBtnItem:ctor(p)
	self:superCall("ctor", p)
end

function Lua_ExpeditionStoreBtnItem:buildShowItem()
	self:superCall("buildShowItem")

	self.nameBg = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_toggle_004_b", 0, 0, 0, 0);
	self.nameBg:addClickFuntion(self, self.onPressClick);

	self.nameText = UICreate.createLabel(self.content, nil, 0, 3, 100, 31, 28);
	self.nameText.pivotValue = 4;
	self.nameText.alignmentValue = 4;
	self.nameText.horizontalOverflowValue = 1;
	self.nameText.verticalOverflowValue = 1;
	self.nameText.fontName = Lua_MyUISettings.huakangFontName;
end

function Lua_ExpeditionStoreBtnItem:setData(data)
	self.data = data;
	local config = getConfig("expedition_map", data.stage_id);
	self.nameText.text = LanUtil.formateStr(330001, tostring(config.station));
end

function Lua_ExpeditionStoreBtnItem:setSelected(index)
	self:superCall("setSelected", index)
	if index == self.index then -- 选中
		self.nameBg:setAltas("common_altas_3", "xui_common_toggle_004_f");
		self.nameText.colorStr = Lua_ColorDefine.transColor("8B5E34");
	else
		self.nameBg:setAltas("common_altas_3", "xui_common_toggle_004_b");
		self.nameText.colorStr = Lua_ColorDefine.transColor("877566");
	end
end










Lua_ExpeditionStoreItem = class("Lua_ExpeditionStoreItem", Lua_ListCell)
function Lua_ExpeditionStoreItem:ctor(p)
	self:superCall("ctor", p, "ExpeditionDiscountStoreItem_skin");
end

function Lua_ExpeditionStoreItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setSiblingIndex(0);

	self.btnBuy:setMouseEnable(false);
	self.btnBuy:addClickFuntion(self, self.onBtnBuyClick);
end

function Lua_ExpeditionStoreItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.costIconItem then
		self.costIconItem:dispose();
		self.costIconItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionStoreItem:setData(data)
	self.data = data;
	local config = DataCenter.expeditionUtil:getStoreInfo(data.shop_id);

	local itemVo = Lua_ToolVo.createToolVo(config.item[1], config.item[2]);
	self.itemIcon:setData(itemVo);

	if config.discount and config.discount > 0 then
		self.discount_bg:setEnable(true);
		self.discount:setEnable(true);
		self.discount.text = LanUtil.formateStr(330039, tostring(config.discount));
	else
		self.discount_bg:setEnable(false);
		self.discount:setEnable(false);
	end

	if data.buyed_times > 0 then
		self.btnBuy:setMouseEnable(false);
		self.btnBuy:setStyle(3);
		self.btnBuy.txt.colorStr = Lua_ColorDefine.transColorStr("7A6A5F");
		self.btnBuy:setLangValue(330030);
		if self.costIconItem then
			self.costIconItem:setEnable(false);
		end
	else
		if self.costIconItem == nil then
			self.costIconItem = Lua_ConsumeIconItem.new(self.content);
			self.costIconItem:setLocation(0, -105, 0);
			self.costIconItem:setStyle(Lua_MyUISettings.huakangFontName, 26);
		end
		self.costIconItem:setEnable(true);
		itemVo = Lua_ToolVo.createToolVo(config.cost[1], config.cost[2]);

		self.btnBuy:setStyle(1);
		self.btnBuy:setMouseEnable(true);
		self.btnBuy.label = nil;
		self.costIconItem:setData(itemVo, nil, Lua_ColorDefine.getColorStr("8B5E34", itemVo.count));
	end
end

function Lua_ExpeditionStoreItem:onPressClick()
	DataCenter.packUtil:showItemInfo(self.itemIcon.data);
end

function Lua_ExpeditionStoreItem:onBtnBuyClick(go)
	local config = DataCenter.expeditionUtil:getStoreInfo(self.data.shop_id);
	local costId = DataCenter.packData:checkConsumeEnough(config.cost);
	if costId == nil then
		Lua_MsgUtil.callFunc("EXPEDITION_DISCOUNTSTORE_SELECT", self.data);
	else
		DataCenter.packUtil:openPathWindow(costId);
	end
end